ingredients = [
    'apricot', 'broccoli', 'cherry', 'date', 'elderberry',
    'fig', 'grape', 'honeydew', 'iceberg', 'jalapeno',
    'kiwi', 'lime', 'mushroom', 'nectarine', 'olive',
    'pumpkin', 'quince', 'raspberry', 'strawberry', 'tangerine',
    'uglifruit', 'vanilla', 'watermelon', 'xigua', 'yam', 'zucchini'
]